@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2017 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #include <cpl_func.h>
 
 #include <cxutils.h>
- 
+
 CPL_BEGIN_DECLS
 
 /*
@@ -65,17 +65,17 @@ CPL_BEGIN_DECLS
  */
 /*----------------------------------------------------------------------------*/
 #ifndef CPL_HAVE_VA_ARGS
-#   if !defined __STDC_VERSION__ && defined __STRICT_ANSI__
-      /* (llvm-)gcc -ansi and (llvm-)gcc -std=c89 do not define __STDC_VERSION__
+#if !defined __STDC_VERSION__ && defined __STRICT_ANSI__
+/* (llvm-)gcc -ansi and (llvm-)gcc -std=c89 do not define __STDC_VERSION__
          but they do define __STRICT_ANSI__ */
-#     define CPL_HAVE_VA_ARGS 0
-#  else
-    /* (llvm-)gcc with other language standards (incl. gnu89 (equivalent to
+#define CPL_HAVE_VA_ARGS 0
+#else
+/* (llvm-)gcc with other language standards (incl. gnu89 (equivalent to
        no language specification), iso9899:199409, c99) reaches this point */
-    /* Sunstudio 12.1 c99 reaches this point since it defines __STDC_VERSION__
+/* Sunstudio 12.1 c99 reaches this point since it defines __STDC_VERSION__
        to 199901L as expected (it also defines __STRICT_ANSI__) */
-#     define CPL_HAVE_VA_ARGS 1
-#  endif
+#define CPL_HAVE_VA_ARGS 1
+#endif
 #endif
 
 /*----------------------------------------------------------------------------*/
@@ -170,27 +170,34 @@ CPL_BEGIN_DECLS
 /*----------------------------------------------------------------------------*/
 
 #if defined CPL_HAVE_VA_ARGS && CPL_HAVE_VA_ARGS == 1 || defined DOXYGEN_SKIP
-#define cpl_error_ensure(CONDITION, CODE, ACTION, ...)                         \
-    do if (CPL_UNLIKELY(!(CONDITION))) {                                       \
-        /* Evaluate exactly once using a name-space protected variable name */ \
-        const cpl_error_code cpl_ensure_error = (CODE);                        \
-        (void)cpl_error_set_message_macro(cpl_func, cpl_ensure_error           \
-                                          ? cpl_ensure_error :                 \
-                                          CPL_ERROR_UNSPECIFIED,               \
-                                           __FILE__, __LINE__, __VA_ARGS__);   \
-        ACTION;                                                                \
-    } while (0)
+#define cpl_error_ensure(CONDITION, CODE, ACTION, ...)                             \
+    do                                                                             \
+        if (CPL_UNLIKELY(!(CONDITION))) {                                          \
+            /* Evaluate exactly once using a name-space protected variable name */ \
+            const cpl_error_code cpl_ensure_error = (CODE);                        \
+            (void)cpl_error_set_message_macro(cpl_func,                            \
+                                              cpl_ensure_error                     \
+                                                  ? cpl_ensure_error               \
+                                                  : CPL_ERROR_UNSPECIFIED,         \
+                                              __FILE__, __LINE__,                  \
+                                              __VA_ARGS__);                        \
+            ACTION;                                                                \
+        }                                                                          \
+    while (0)
 #else
-#define cpl_error_ensure(CONDITION, CODE, ACTION, MSG)                         \
-    do if (CPL_UNLIKELY(!(CONDITION))) {                                       \
-        /* Evaluate exactly once using a name-space protected variable name */ \
-        const cpl_error_code cpl_ensure_error = (CODE);                        \
-        (void)cpl_error_set_message_one_macro(cpl_func, cpl_ensure_error       \
-                                              ? cpl_ensure_error :             \
-                                              CPL_ERROR_UNSPECIFIED,           \
-                                              __FILE__, __LINE__, MSG);        \
-        ACTION;                                                                \
-    } while (0)
+#define cpl_error_ensure(CONDITION, CODE, ACTION, MSG)                             \
+    do                                                                             \
+        if (CPL_UNLIKELY(!(CONDITION))) {                                          \
+            /* Evaluate exactly once using a name-space protected variable name */ \
+            const cpl_error_code cpl_ensure_error = (CODE);                        \
+            (void)cpl_error_set_message_one_macro(cpl_func,                        \
+                                                  cpl_ensure_error                 \
+                                                      ? cpl_ensure_error           \
+                                                      : CPL_ERROR_UNSPECIFIED,     \
+                                                  __FILE__, __LINE__, MSG);        \
+            ACTION;                                                                \
+        }                                                                          \
+    while (0)
 #endif
 
 
@@ -211,8 +218,8 @@ CPL_BEGIN_DECLS
 
  */
 /*----------------------------------------------------------------------------*/
-#define cpl_ensure(BOOL, ERRCODE, RETURN)                                      \
- cpl_error_ensure(BOOL, ERRCODE, return(RETURN), " ")
+#define cpl_ensure(BOOL, ERRCODE, RETURN) \
+    cpl_error_ensure(BOOL, ERRCODE, return (RETURN), " ")
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -225,8 +232,8 @@ CPL_BEGIN_DECLS
 
  */
 /*----------------------------------------------------------------------------*/
-#define cpl_ensure_code(BOOL, ERRCODE)                                         \
- cpl_error_ensure(BOOL, ERRCODE, return(cpl_error_get_code()), " ")
+#define cpl_ensure_code(BOOL, ERRCODE) \
+    cpl_error_ensure(BOOL, ERRCODE, return (cpl_error_get_code()), " ")
 
 
 /**
@@ -248,7 +255,7 @@ CPL_BEGIN_DECLS
  */
 
 #define cpl_error_set(function, code) \
-        cpl_error_set_message_macro(function, code, __FILE__, __LINE__, " ")
+    cpl_error_set_message_macro(function, code, __FILE__, __LINE__, " ")
 
 
 /**
@@ -275,9 +282,9 @@ CPL_BEGIN_DECLS
  * @hideinitializer
  */
 
-#define cpl_error_set_where(function)                                          \
-       cpl_error_set_message_macro(function, cpl_error_get_code(),             \
-                                    __FILE__, __LINE__, " ")
+#define cpl_error_set_where(function)                                     \
+    cpl_error_set_message_macro(function, cpl_error_get_code(), __FILE__, \
+                                __LINE__, " ")
 
 /**
  * @ingroup cpl_error
@@ -341,10 +348,10 @@ CPL_BEGIN_DECLS
  * @hideinitializer
  */
 #if defined CPL_HAVE_VA_ARGS && CPL_HAVE_VA_ARGS == 1 || defined DOXYGEN_SKIP
-#define cpl_error_set_message(function, code, ...)                             \
+#define cpl_error_set_message(function, code, ...) \
     cpl_error_set_message_macro(function, code, __FILE__, __LINE__, __VA_ARGS__)
 #else
-#define cpl_error_set_message(function, code, text)                        \
+#define cpl_error_set_message(function, code, text) \
     cpl_error_set_message_one_macro(function, code, __FILE__, __LINE__, text)
 #endif
 
@@ -384,8 +391,9 @@ CPL_BEGIN_DECLS
 
  */
 
-enum _cpl_error_code_ {
-    CPL_ERROR_NONE = 0,         
+enum _cpl_error_code_
+{
+    CPL_ERROR_NONE = 0,
     /**< No error condition */
     CPL_ERROR_UNSPECIFIED = 1,
     /**< An unspecified error */
@@ -395,37 +403,37 @@ enum _cpl_error_code_ {
     /**< Could not duplicate output stream */
     CPL_ERROR_ASSIGNING_STREAM,
     /**< Could not associate a stream with a file descriptor */
-    CPL_ERROR_FILE_IO,          
+    CPL_ERROR_FILE_IO,
     /**< Permission denied */
-    CPL_ERROR_BAD_FILE_FORMAT,  
+    CPL_ERROR_BAD_FILE_FORMAT,
     /**< Input file had not the expected format */
     CPL_ERROR_FILE_ALREADY_OPEN,
     /**< Attempted to open a file twice */
-    CPL_ERROR_FILE_NOT_CREATED, 
+    CPL_ERROR_FILE_NOT_CREATED,
     /**< Could not create a file */
-    CPL_ERROR_FILE_NOT_FOUND,   
+    CPL_ERROR_FILE_NOT_FOUND,
     /**< A specified file or directory was not found */
-    CPL_ERROR_DATA_NOT_FOUND,           
+    CPL_ERROR_DATA_NOT_FOUND,
     /**< Data searched within a valid object were not found */
-    CPL_ERROR_ACCESS_OUT_OF_RANGE,      
+    CPL_ERROR_ACCESS_OUT_OF_RANGE,
     /**< Data were accessed beyond boundaries */
-    CPL_ERROR_NULL_INPUT,               
+    CPL_ERROR_NULL_INPUT,
     /**< A @c NULL pointer was found where a valid pointer was expected */
-    CPL_ERROR_INCOMPATIBLE_INPUT,       
+    CPL_ERROR_INCOMPATIBLE_INPUT,
     /**< Data that had to be processed together did not match */
-    CPL_ERROR_ILLEGAL_INPUT,            
+    CPL_ERROR_ILLEGAL_INPUT,
     /**< Illegal values were detected */
-    CPL_ERROR_ILLEGAL_OUTPUT,           
+    CPL_ERROR_ILLEGAL_OUTPUT,
     /**< A given operation would have generated an illegal object */
-    CPL_ERROR_UNSUPPORTED_MODE,         
+    CPL_ERROR_UNSUPPORTED_MODE,
     /**< The requested functionality is not supported */
-    CPL_ERROR_SINGULAR_MATRIX,          
+    CPL_ERROR_SINGULAR_MATRIX,
     /**< Could not invert a matrix */
-    CPL_ERROR_DIVISION_BY_ZERO,         
+    CPL_ERROR_DIVISION_BY_ZERO,
     /**< Attempted to divide a number by zero */
-    CPL_ERROR_TYPE_MISMATCH,             
+    CPL_ERROR_TYPE_MISMATCH,
     /**< Data were not of the expected type */
-    CPL_ERROR_INVALID_TYPE,         
+    CPL_ERROR_INVALID_TYPE,
     /**< Data type was unsupported or invalid */
     CPL_ERROR_CONTINUE,
     /**< An iterative process did not converge */
@@ -450,32 +458,35 @@ typedef struct _cpl_error_ cpl_error;
                               Function prototypes
  -----------------------------------------------------------------------------*/
 
-void           cpl_error_reset(void);
-cpl_error_code
-cpl_error_set_message_macro(const char *, cpl_error_code,
-                            const char *, unsigned,
-                            const char *, ...) CPL_ATTR_PRINTF(5,6)
-#ifdef CPL_HAVE_ATTR_NONNULL
-    __attribute__((nonnull(3)))
-#endif
-     ;
-
-cpl_error_code
-cpl_error_set_message_one_macro(const char *, cpl_error_code,
-                                const char *, unsigned,
-                                const char *)
+void cpl_error_reset(void);
+cpl_error_code cpl_error_set_message_macro(const char *,
+                                           cpl_error_code,
+                                           const char *,
+                                           unsigned,
+                                           const char *,
+                                           ...) CPL_ATTR_PRINTF(5, 6)
 #ifdef CPL_HAVE_ATTR_NONNULL
     __attribute__((nonnull(3)))
 #endif
     ;
 
-cpl_error_code  cpl_error_get_code(void)     CPL_ATTR_PURE;
-const char     *cpl_error_get_message(void)  CPL_ATTR_PURE;
-const char     *cpl_error_get_message_default(cpl_error_code) CPL_ATTR_CONST;
-const char     *cpl_error_get_function(void) CPL_ATTR_PURE;
-const char     *cpl_error_get_file(void)     CPL_ATTR_PURE;
-unsigned        cpl_error_get_line(void)     CPL_ATTR_PURE;
-const char     *cpl_error_get_where(void)    CPL_ATTR_PURE;
+cpl_error_code cpl_error_set_message_one_macro(const char *,
+                                               cpl_error_code,
+                                               const char *,
+                                               unsigned,
+                                               const char *)
+#ifdef CPL_HAVE_ATTR_NONNULL
+    __attribute__((nonnull(3)))
+#endif
+    ;
+
+cpl_error_code cpl_error_get_code(void) CPL_ATTR_PURE;
+const char *cpl_error_get_message(void) CPL_ATTR_PURE;
+const char *cpl_error_get_message_default(cpl_error_code) CPL_ATTR_CONST;
+const char *cpl_error_get_function(void) CPL_ATTR_PURE;
+const char *cpl_error_get_file(void) CPL_ATTR_PURE;
+unsigned cpl_error_get_line(void) CPL_ATTR_PURE;
+const char *cpl_error_get_where(void) CPL_ATTR_PURE;
 
 CPL_END_DECLS
 
