@@ -169,9 +169,7 @@ cpl_propertylist_append_from_string(cpl_propertylist *self,
 
     if (keylen + 1 >= FLEN_KEYWORD) {
         return cpl_error_set_message_(CPL_ERROR_BAD_FILE_FORMAT,
-                                      "FITS Card "
-                                      "has bad key (len=%d)",
-                                      keylen);
+                                      "FITS Card has bad key (len=%d)", keylen);
     }
 
     if (names != NULL) {
@@ -297,10 +295,8 @@ cpl_propertylist_append_from_string(cpl_propertylist *self,
             keystr[keylen] = '\0';
             return cpl_error_set_message_(
                 CPL_ERROR_BAD_FILE_FORMAT,
-                "Bad value "
-                "in FITS card with key='%*s', "
-                "bytepos(=): %d, bad-byte=0x%02x (\"%s\") "
-                "at pos: %d",
+                "Bad value in FITS card with key='%*s', bytepos(=): %d, "
+                "bad-byte=0x%02x (\"%s\") at pos: %d",
                 keylen, keystr, valinlen, (int)*badchar, badchar, compos);
         }
     }
@@ -670,7 +666,6 @@ cpl_fits_set_value_(char *strval,
             if (fptype0 == FP_NAN || fptype0 == FP_INFINITE ||
                 fptype1 == FP_NAN || fptype1 == FP_INFINITE) {
                 (void)cpl_error_set_message_(CPL_ERROR_ILLEGAL_INPUT,
-                                             ""
                                              "FITS does not allow special "
                                              "float complex: %s",
                                              retval);
@@ -694,7 +689,6 @@ cpl_fits_set_value_(char *strval,
             if (fptype0 == FP_NAN || fptype0 == FP_INFINITE ||
                 fptype1 == FP_NAN || fptype1 == FP_INFINITE) {
                 (void)cpl_error_set_message_(CPL_ERROR_ILLEGAL_INPUT,
-                                             ""
                                              "FITS does not allow special "
                                              "double complex: %s",
                                              retval);
@@ -793,9 +787,8 @@ cpl_fits_set_value_(char *strval,
         cx_assert(type != CPL_TYPE_STRING);
         retval[*plen] = '\0'; /* Cannot overflow string buffer */
         (void)cpl_error_set_message_(CPL_ERROR_ILLEGAL_INPUT,
-                                     "Key + '%s'-"
-                                     "value too long for FITS card: %d < %d "
-                                     "(%*s)",
+                                     "Key + '%s'-value too long for FITS card: "
+                                     "%d < %d (%*s)",
                                      cpl_type_get_name(type), *plen, maxlen,
                                      *plen, retval);
         return NULL;
@@ -899,8 +892,10 @@ cpl_fits_key_is_comment(const cpl_cstr *keywlen)
     }
 
     /* Key is not blank, skip (remaining) initial+trailing blanks */
-    while (CPL_UNLIKELY(*key == ' '))
+    while (CPL_UNLIKELY(*key == ' ')) {
         key++; /* Skip initial blanks */
+        wlen--;
+    }
     while (CPL_UNLIKELY(key[wlen - 1] == ' '))
         wlen--; /* Skip trailing blanks */
 
@@ -961,8 +956,10 @@ cpl_fits_set_key(char *card,
     }
 
     /* Key is not blank, skip (remaining) initial+trailing blanks */
-    while (CPL_UNLIKELY(*key == ' '))
+    while (CPL_UNLIKELY(*key == ' ')) {
         key++; /* Skip initial blanks */
+        wlen--;
+    }
     while (CPL_UNLIKELY(key[wlen - 1] == ' '))
         wlen--; /* Skip trailing blanks */
 
@@ -997,8 +994,7 @@ cpl_fits_set_key(char *card,
         }
         else {
             (void)cpl_error_set_message_(CPL_ERROR_ILLEGAL_INPUT,
-                                         "FITS "
-                                         "HIERARCH key too long: %d > %d",
+                                         "FITS HIERARCH key too long: %d > %d",
                                          (int)wlen, FLEN_KEYWORD - 2);
             return -1;
         }
@@ -1044,9 +1040,7 @@ cpl_fits_set_key(char *card,
             const char checkchar[2] = { checksum & 0x7f, '\0' };
             (void)cpl_error_set_message_(
                 CPL_ERROR_ILLEGAL_INPUT,
-                "Bad %d-"
-                "character FITS key (\"%*s\") w. mask: "
-                "0x%02x (\"%s\")",
+                "Bad %d-character FITS key (\"%*s\") w. mask: 0x%02x (\"%s\")",
                 (int)wlen, (int)wlen, key, (int)*checkchar, checkchar);
             return -1;
         }
@@ -1155,6 +1149,10 @@ cpl_fits_get_key(const char *card, int *plen, int *piparsed)
   If the string has neither but the conversion to a signed long long int
   causes an overflow, the resulting number is deemed float.
 
+  The use of strtod() is lenient to silently allow certain strings that
+  are not strictly FITS to still be accepted with the value returned by
+  strtod() as long as the value is normal or zero, e.g. 42e1.
+
  */
 /*----------------------------------------------------------------------------*/
 inline static int
@@ -1202,10 +1200,12 @@ cpl_fits_get_number(const char *card,
 
         char numparse[FLEN_VALUE];
 
-        (void)memcpy(numparse, card + iparsed, FITS_CARD_LEN - iparsed);
+        cx_assert(FITS_CARD_LEN - iparsed + 1 <= FLEN_VALUE);
+
+        /* Card has null terminator, copy it as well */
+        (void)memcpy(numparse, card + iparsed, FITS_CARD_LEN - iparsed + 1);
 
         numparse[endptr - (card + iparsed)] = 'E';
-        numparse[FITS_CARD_LEN - iparsed] = '\0';
 
         errno = 0; /* Floating-point parsing can result in overflow, ERANGE */
         *pdval = strtod(numparse, &endptr);
@@ -1413,7 +1413,7 @@ cpl_fits_get_value(cpl_fits_value *pparseval,
                     }
                     break;
                 }
-                case '/': /* Undefinded value - with a comment */
+                case '/': /* Undefined value - with a comment */
                     pparseval->nmemb = 0;
                     pparseval->tcode = 'U';
                     break; /* No value found, so do not advance iparsed */
@@ -1458,11 +1458,13 @@ cpl_fits_get_value(cpl_fits_value *pparseval,
                 /* Found value. Look for comment */
 
                 const char *comchar;
+                /* Cast to avoid gcc-warning: Wstringop-overread */
+                const size_t remsize = FITS_CARD_LEN - (size_t)iparsed;
 
                 cx_assert(iparsed >= 0);
                 cx_assert(iparsed <= FITS_CARD_LEN);
 
-                comchar = memchr(card + iparsed, '/', FITS_CARD_LEN - iparsed);
+                comchar = memchr(card + iparsed, '/', remsize);
 
                 *pjparsed = CPL_LIKELY(comchar != NULL)
                                 ? (int)(comchar - card) /* Start of comment */
@@ -1718,7 +1720,7 @@ cpl_fits_get_comment(const char *card, int jparsed, int *plen)
 /*----------------------------------------------------------------------------*/
 /**
   @internal
-  @brief Deallocate memory used for checkning key uniqueness
+  @brief Deallocate memory used for checking key uniqueness
   @param putkey   Array of keys arrays already written, ordered after length
   @return Nothing
   @note (Almost) no input validation in this internal function
@@ -1759,6 +1761,26 @@ cpl_fits_key_free_unique(const char **putkey[])
 #endif
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @internal
+  @brief Reset memory used for checking key uniqueness
+  @param putkey   Array of keys arrays already written, ordered after length
+  @return Nothing
+  @note (Almost) no input validation in this internal function
+
+ */
+/*----------------------------------------------------------------------------*/
+static void
+cpl_fits_key_reset_unique(const char **putkey[])
+{
+    for (cpl_size i = 0; i < FLEN_KEYWORD; i++) {
+        if (putkey[i]) {
+            putkey[i][0] = NULL;
+        }
+    }
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @internal
@@ -1773,14 +1795,15 @@ cpl_fits_key_free_unique(const char **putkey[])
     do {                                                                \
         cpl_size i = 0;                                                 \
         if (putkey[KLEN] != NULL) {                                     \
-            do {                                                        \
+            while (putkey[KLEN][i] != NULL) {                           \
                 if (!memcmp(putkey[KLEN][i], keyname, KLEN))            \
                     return 1;                                           \
-            } while (putkey[KLEN][++i] != NULL);                        \
+                i++;                                                    \
+            };                                                          \
         }                                                               \
         else {                                                          \
             /* One extra for the NULL-terminator */                     \
-            putkey[KLEN] = cpl_malloc((ntocheck + 2) * sizeof(char *)); \
+            putkey[KLEN] = cpl_malloc((ntocheck + 1) * sizeof(char *)); \
         }                                                               \
                                                                         \
         putkey[KLEN][i] = keyname;                                      \
@@ -1804,16 +1827,17 @@ cpl_fits_key_free_unique(const char **putkey[])
     do {                                                                    \
         cpl_size i = 0;                                                     \
         if (putkey[KLEN] != NULL) {                                         \
-            do {                                                            \
+            while (putkey[KLEN][i] != NULL) {                               \
                 if (!memcmp(putkey[KLEN][i] + KLEN - 8, keyname + KLEN - 8, \
                             8) &&                                           \
                     !memcmp(putkey[KLEN][i], keyname, KLEN - 8))            \
                     return 1;                                               \
-            } while (putkey[KLEN][++i] != NULL);                            \
+                i++;                                                        \
+            };                                                              \
         }                                                                   \
         else {                                                              \
             /* One extra for the NULL-terminator */                         \
-            putkey[KLEN] = cpl_malloc((ntocheck + 2) * sizeof(char *));     \
+            putkey[KLEN] = cpl_malloc((ntocheck + 1) * sizeof(char *));     \
         }                                                                   \
                                                                             \
         putkey[KLEN][i] = keyname;                                          \
@@ -1836,11 +1860,6 @@ cpl_fits_key_free_unique(const char **putkey[])
   length, so the actual string comparison is done only on keys with matching
   lengths, reducing the number of memcmp() calls.
 
-  An option would also be to group the already seen keys according to their
-  sortkey. However, with the grouping according to length, and with keys that
-  do not share the sorting key typically differing within their first 8 bytes,
-  this is not worth the added complexity and increased number of buffers.
-
  */
 /*----------------------------------------------------------------------------*/
 inline static int
