@@ -82,9 +82,9 @@
  * @note The function must be called once before any other CPL function.
  * @see cpl_fits_set_mode()
  *
- * This function sets up the library internal subsystems, which other 
+ * This function sets up the library internal subsystems, which other
  * CPL functions expect to be in a defined state. In particular, the CPL
- * memory management and the CPL messaging systems are initialised by 
+ * memory management and the CPL messaging systems are initialised by
  * this function call.
  *
  * One of the internal subsystems of CPL handles memory allocation.
@@ -100,7 +100,7 @@
  *    of invalid pointers.
  * Any other value (including NULL) will leave the default memory mode
  * unchanged.
- * 
+ *
  * This function also reads the environment variable @em CPL_IO_MODE.
  * Iff set to 1, cpl_fits_set_mode() is called with CPL_FITS_START_CACHING.
  *
@@ -141,20 +141,6 @@ cpl_init(unsigned self)
         cpl_msg_warning(cpl_func, "Illegal input ignored");
     }
 
-    float _cfitsio_version;
-    const int cfitsio_version_min =
-        (int)(100. * CPL_CFITSIO_MAJOR + CPL_CFITSIO_MINOR);
-    const int cfitsio_version =
-        (int)(100. * fits_get_version(&_cfitsio_version));
-
-    if (cfitsio_version < cfitsio_version_min) {
-        (void)cpl_error_set_message_(CPL_ERROR_INCOMPATIBLE_INPUT,
-                                     "Run-time version %.3f of CFITSIO "
-                                     "is not supported. Minimum required "
-                                     "version  is %.3f",
-                                     _cfitsio_version, CPL_CFITSIO_VERSION);
-    }
-
 #ifdef HAVE_LIBPTHREAD
     cpl_error_init_locks();
 #endif
@@ -264,7 +250,7 @@ cpl_get_description(unsigned self)
  *
  * This function must be called after any other CPL function
  * is called.
- * 
+ *
  */
 
 void
