@@ -168,8 +168,9 @@ typedef struct _cpl_property_
                         Private function prototypes
  -----------------------------------------------------------------------------*/
 
-static cpl_property *cpl_property_new_(const char *, cpl_type, cpl_size, size_t)
-    CPL_ATTR_ALLOC CPL_ATTR_NONNULL;
+static cpl_property *
+cpl_property_new_(const char *, cpl_type, cpl_size, size_t)
+CPL_ATTR_ALLOC CPL_ATTR_NONNULL;
 
 inline static void
 cpl_property_update_(cpl_property *, const cpl_property *) CPL_ATTR_NONNULL;
@@ -853,6 +854,9 @@ cpl_property_get_type(const cpl_property *self)
  * @param self  The property.
  * @param name  New name.
  *
+ * @return
+ *   Nothing
+ *
  * @see cpl_property_set_name
  *
  */
@@ -960,9 +964,7 @@ cpl_property_set_name(cpl_property *self, const char *name)
  * @param comment  New comment.
  *
  * @return
- *   The function returns @c CPL_ERROR_NONE on success and an appropriate
- *   error code if an error occurred. In the latter case the error code is
- *   also set in the error handling system.
+ *   Nothing
  *
  * @error
  *   <table class="ec" align="center">
@@ -1470,6 +1472,9 @@ cpl_property_set_double(cpl_property *self, double value)
  * @param self   The property.
  * @param value  New value.
  *
+ * @return
+ *   Nothing
+ *
  * @see cpl_property_set_string()
  *
  */
@@ -2681,12 +2686,13 @@ cpl_property_compare_sortkey(const cpl_property *p1, const cpl_property *p2)
 /**
  * @internal
  * @brief
- *   Get the sort key of a property.
+ *   Set the sort key of a property.
  *
- * @param self  The property.
+ * @param self    The property.
+ * @param sortkey The sort key
  *
  * @return
- *   The sort code of this property.
+ *   Nothing
  *
  * @note No error checking in this internal function
  */
