@@ -66,7 +66,7 @@
 void
 cpl_property_set_sortkey_dicb(cpl_property *self)
 {
-    const size_t size = cpl_property_get_size_name(self) + 1;
+    const size_t size = cpl_property_get_size_name(self);
     const char *key = cpl_property_get_name_(self);
 
     /* The default value for a FITS key of length less than 9 */
@@ -82,17 +82,17 @@ cpl_property_set_sortkey_dicb(cpl_property *self)
     /* NB: The indentation that aligns the calls to memcmp() helps to
        ensure that strings of identical length share the correct branch */
 
-    switch (size) { /* The number of characters includes the null-byte */
+    switch (size) { /* The number of characters excludes the null-byte */
+        case 0:
         case 1:
-        case 2:
             break;
 
-        case 3:
+        case 2:
             if (!memcmp(key, "RA", 2))
                 kt = CPL_DICB_DESCRIBE;
             break;
 
-        case 4:
+        case 3:
             if (!memcmp(key, "DEC", 3))
                 kt = CPL_DICB_DESCRIBE;
             else if (!memcmp(key, "LST", 3))
@@ -103,12 +103,12 @@ cpl_property_set_sortkey_dicb(cpl_property *self)
                 kt = CPL_DICB_END;
             break;
 
-        case 5:
+        case 4:
             if (!memcmp(key, "DATE", 4))
                 kt = CPL_DICB_DESCRIBE;
             break;
 
-        case 6:
+        case 5:
             if (!memcmp(key, "BZERO", 5))
                 kt = CPL_DICB_BZERO;
             else if (!memcmp(key, "NAXIS", 5))
@@ -129,7 +129,7 @@ cpl_property_set_sortkey_dicb(cpl_property *self)
 
             break;
 
-        case 7:
+        case 6:
             if (!memcmp(key, "BITPIX", 6))
                 kt = CPL_DICB_BITPIX;
             else if (!memcmp(key, "BSCALE", 6))
@@ -196,7 +196,7 @@ cpl_property_set_sortkey_dicb(cpl_property *self)
                 }
             }
             break;
-        case 8:
+        case 7:
             if (!memcmp(key, "HISTORY", 7))
                 kt = CPL_DICB_HISTORY;
             else if (!memcmp(key, "COMMENT", 7))
@@ -213,6 +213,8 @@ cpl_property_set_sortkey_dicb(cpl_property *self)
                 kt = CPL_DICB_DESCRIBE;
             else if (!memcmp(key, "TIMESYS", 7))
                 kt = CPL_DICB_DESCRIBE;
+            else if (!memcmp(key, "RADESYS", 7))
+                kt = CPL_DICB_DESCRIBE;
             else if (!memcmp(key, "WCSAXES", 7))
                 kt = CPL_DICB_WCS;
             else if (!memcmp(key, "WCSNAME", 7))
@@ -279,7 +281,7 @@ cpl_property_set_sortkey_dicb(cpl_property *self)
             }
             break;
 
-        case 9:
+        case 8:
             if (!memcmp(key, "XTENSION", 8))
                 kt = CPL_DICB_TOP;
             else if (!memcmp(key, "TELESCOP", 8))
