@@ -224,15 +224,9 @@ CPL_BEGIN_DECLS
     } while (0)
 
 
-#if defined HAVE_LONG_DOUBLE && HAVE_LONG_DOUBLE == 1
 typedef long double cpl_long_double;
 #define CPL_LDBL_EPSILON     LDBL_EPSILON
 #define CPL_LDBL_EPSILON_STR "LDBL_EPSILON"
-#else
-typedef double cpl_long_double;
-#define CPL_LDBL_EPSILON     DBL_EPSILON
-#define CPL_LDBL_EPSILON_STR "DBL_EPSILON"
-#endif
 
 /*----------------------------------------------------------------------------*/
 /**
