@@ -53,6 +53,7 @@ static void cpl_vector_save_bench(int);
 static void cpl_vector_get_stdev_bench(int);
 static void cpl_vector_corr_bench(int);
 static void cpl_vector_fit_gaussian_test_one(FILE *);
+static void cpl_vector_fit_gaussian_test_2(void);
 static void cpl_vector_valarray_bench_one(cpl_vector *, cpl_vector *);
 static void cpl_vector_valarray_bench(cpl_size);
 /*-----------------------------------------------------------------------------
@@ -116,6 +117,7 @@ main(void)
     cpl_vector_cycle_test(VECTOR_SIZE + 1);
 
     cpl_vector_fit_gaussian_test_one(stream);
+    cpl_vector_fit_gaussian_test_2();
 
     null = cpl_vector_new(0);
 
@@ -1253,6 +1255,53 @@ cpl_vector_fit_gaussian_test_one(FILE *stream)
     cpl_matrix_delete(matrix);
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Reproduce PIPE-10284
+  @return   void
+ */
+/*----------------------------------------------------------------------------*/
+static void
+cpl_vector_fit_gaussian_test_2(void)
+{
+    double xdata[] = { 4092, 4093, 4094, 4095 };
+    double ydata[] = { 0.176547, 0.628888, 2.50761, 30.4113 };
+    double ysigd[] = { 0.092203, 0.092203, 0.092203, 0.092203 };
+
+    cpl_vector *x = cpl_vector_wrap(4, xdata);
+    cpl_vector *y = cpl_vector_wrap(4, ydata);
+    cpl_vector *sigma_y = cpl_vector_wrap(4, ysigd);
+
+    double x0, sigma, area, offset, mse;
+    cpl_matrix *covariance = NULL;
+
+    cpl_error_code code =
+        cpl_vector_fit_gaussian(x, NULL, y, sigma_y, CPL_FIT_ALL, &x0, &sigma,
+                                &area, &offset, &mse, NULL, NULL);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code =
+        cpl_vector_fit_gaussian(x, NULL, y, sigma_y, CPL_FIT_ALL, &x0, &sigma,
+                                &area, &offset, &mse, NULL, &covariance);
+
+    /* The test case is ill-conditioned, so may fail - on some platforms */
+    if (code != CPL_ERROR_NONE) {
+        cpl_test_eq_error(code, CPL_ERROR_SINGULAR_MATRIX);
+
+        cpl_test_null(covariance);
+    }
+    else {
+        cpl_test_nonnull(covariance);
+        cpl_matrix_delete(covariance);
+    }
+
+    cpl_vector_unwrap(x);
+    cpl_vector_unwrap(y);
+    cpl_vector_unwrap(sigma_y);
+
+    return;
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Perform a number of benchmarks
