@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2017 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,17 +38,17 @@
                                    Define
  -----------------------------------------------------------------------------*/
 
-#define IMAGESZ     10
-#define IMAGESZ2    512
-
-#define CPL_APERTS_CMP_IMAGE(OP)                                               \
-    do {                                                                       \
-        cpl_test_abs( CPL_CONCAT(cpl_apertures_get, OP)(aperts, 1),            \
-                      CPL_CONCAT2X(cpl_image_get, CPL_CONCAT(OP,window))       \
-                      (imb, 1, 1, IMAGESZ, IMAGESZ),                           \
-                       4.0 * DBL_EPSILON);                                     \
-    } while (0)    
+#define IMAGESZ  10
+#define IMAGESZ2 512
 
+#define CPL_APERTS_CMP_IMAGE(OP)                                              \
+    do {                                                                      \
+        cpl_test_abs(CPL_CONCAT(cpl_apertures_get, OP)(aperts, 1),            \
+                     CPL_CONCAT2X(cpl_image_get,                              \
+                                  CPL_CONCAT(OP, window))(imb, 1, 1, IMAGESZ, \
+                                                          IMAGESZ),           \
+                     4.0 * DBL_EPSILON);                                      \
+    } while (0)
 
 
 /*-----------------------------------------------------------------------------
@@ -60,63 +60,58 @@ static void cpl_apertures_test_one(const cpl_apertures *, FILE *);
 /*-----------------------------------------------------------------------------
                                   Main
  -----------------------------------------------------------------------------*/
-int main(void)
+int
+main(void)
 {
-    const cpl_type img_type[] = {CPL_TYPE_DOUBLE, CPL_TYPE_FLOAT, CPL_TYPE_INT};
-    cpl_size (*ap_get_cpl_size[])(const cpl_apertures *, cpl_size) =
-        {cpl_apertures_get_maxpos_x,
-         cpl_apertures_get_maxpos_y,
-         cpl_apertures_get_minpos_x,
-         cpl_apertures_get_minpos_y,
-         cpl_apertures_get_npix,
-         cpl_apertures_get_left,
-         cpl_apertures_get_left_y,
-         cpl_apertures_get_right,
-         cpl_apertures_get_right_y,
-         cpl_apertures_get_top_x,
-         cpl_apertures_get_top,
-         cpl_apertures_get_bottom_x,
-         cpl_apertures_get_bottom};
-    const size_t napsize = sizeof(ap_get_cpl_size)/sizeof(*ap_get_cpl_size);
+    const cpl_type img_type[] = { CPL_TYPE_DOUBLE, CPL_TYPE_FLOAT,
+                                  CPL_TYPE_INT };
+    cpl_size (*ap_get_cpl_size[])(const cpl_apertures *, cpl_size) = {
+        cpl_apertures_get_maxpos_x, cpl_apertures_get_maxpos_y,
+        cpl_apertures_get_minpos_x, cpl_apertures_get_minpos_y,
+        cpl_apertures_get_npix,     cpl_apertures_get_left,
+        cpl_apertures_get_left_y,   cpl_apertures_get_right,
+        cpl_apertures_get_right_y,  cpl_apertures_get_top_x,
+        cpl_apertures_get_top,      cpl_apertures_get_bottom_x,
+        cpl_apertures_get_bottom
+    };
+    const size_t napsize = sizeof(ap_get_cpl_size) / sizeof(*ap_get_cpl_size);
 
     double (*ap_get_double_pos[])(const cpl_apertures *, cpl_size) = {
-        cpl_apertures_get_pos_x,
-        cpl_apertures_get_pos_y,
-        cpl_apertures_get_centroid_x,
-        cpl_apertures_get_centroid_y};
-    const size_t napdpos = sizeof(ap_get_double_pos)/sizeof(*ap_get_double_pos);
+        cpl_apertures_get_pos_x, cpl_apertures_get_pos_y,
+        cpl_apertures_get_centroid_x, cpl_apertures_get_centroid_y
+    };
+    const size_t napdpos =
+        sizeof(ap_get_double_pos) / sizeof(*ap_get_double_pos);
 
     double (*ap_get_double[])(const cpl_apertures *, cpl_size) = {
-        cpl_apertures_get_max,
-        cpl_apertures_get_min,
-        cpl_apertures_get_mean,
-        cpl_apertures_get_median,
-        cpl_apertures_get_stdev,
-        cpl_apertures_get_flux};
-    const size_t napdbl = sizeof(ap_get_double)/sizeof(*ap_get_double);
+        cpl_apertures_get_max,   cpl_apertures_get_min,
+        cpl_apertures_get_mean,  cpl_apertures_get_median,
+        cpl_apertures_get_stdev, cpl_apertures_get_flux
+    };
+    const size_t napdbl = sizeof(ap_get_double) / sizeof(*ap_get_double);
 
-    size_t       isize;
-    cpl_image     * imd;
-    cpl_mask      * bpm;
-    cpl_apertures * aperts;
-    cpl_apertures * nullapert;
-    double        * val;
-    const double    psigmas[] = {5, 2, 1, 0.5};
-    const double    maxval = 10.0;
-    cpl_vector    * sigmas;
-    unsigned        itype;
-    FILE          * stream;
-    cpl_error_code  error;
-    cpl_size        errsize, nsize, pos;
-    cpl_boolean     is_bench;
-    int             nreps, ireps;
+    size_t isize;
+    cpl_image *imd;
+    cpl_mask *bpm;
+    cpl_apertures *aperts;
+    cpl_apertures *nullapert;
+    double *val;
+    const double psigmas[] = { 5, 2, 1, 0.5 };
+    const double maxval = 10.0;
+    cpl_vector *sigmas;
+    unsigned itype;
+    FILE *stream;
+    cpl_error_code error;
+    cpl_size errsize, nsize, pos;
+    cpl_boolean is_bench;
+    int nreps, ireps;
 
     cpl_test_init(PACKAGE_BUGREPORT, CPL_MSG_WARNING);
 
     /* Insert tests below */
 
-    stream = cpl_msg_get_level() > CPL_MSG_INFO
-        ? fopen("/dev/null", "a") : stdout;
+    stream =
+        cpl_msg_get_level() > CPL_MSG_INFO ? fopen("/dev/null", "a") : stdout;
 
     is_bench = cpl_msg_get_level() > CPL_MSG_INFO ? CPL_FALSE : CPL_TRUE;
     nreps = is_bench ? 10 : 1;
@@ -124,8 +119,8 @@ int main(void)
     cpl_msg_info(cpl_func, "Repetitions for benchmarking: %d", nreps);
 
     /* Test 1: NULL pointers */
-    cpl_apertures_delete(NULL); /* Just verify the return */
-    cpl_apertures_dump(NULL, NULL); /* Just verify the return */
+    cpl_apertures_delete(NULL);       /* Just verify the return */
+    cpl_apertures_dump(NULL, NULL);   /* Just verify the return */
     cpl_apertures_dump(NULL, stream); /* Just verify the return */
 
     for (isize = 0; isize < napsize; isize++) {
@@ -192,21 +187,22 @@ int main(void)
     cpl_test_eq_error(error, CPL_ERROR_NONE);
 
     for (ireps = 0; ireps < nreps; ireps++) {
-        for (itype = 0; itype < sizeof(img_type)/sizeof(img_type[0]); itype++) {
+        for (itype = 0; itype < sizeof(img_type) / sizeof(img_type[0]);
+             itype++) {
             const cpl_size naperts = 2;
             const cpl_type type = img_type[itype];
-            cpl_image * labels = cpl_image_new(IMAGESZ, IMAGESZ, CPL_TYPE_INT);
-            cpl_image * img = cpl_image_cast(imd, type);
-            cpl_image * imb = cpl_image_duplicate(img);
-            cpl_mask  * bin;
-            cpl_size    xpos, ypos;
+            cpl_image *labels = cpl_image_new(IMAGESZ, IMAGESZ, CPL_TYPE_INT);
+            cpl_image *img = cpl_image_cast(imd, type);
+            cpl_image *imb = cpl_image_duplicate(img);
+            cpl_mask *bin;
+            cpl_size xpos, ypos;
 
             error = cpl_image_reject_from_mask(imb, bpm);
             cpl_test_eq_error(error, CPL_ERROR_NONE);
 
             /* Create test image and the labels */
-            cpl_msg_info(cpl_func, "Testing with a %d X %d %s-image",
-                         IMAGESZ, IMAGESZ, cpl_type_get_name(type));
+            cpl_msg_info(cpl_func, "Testing with a %d X %d %s-image", IMAGESZ,
+                         IMAGESZ, cpl_type_get_name(type));
 
             /* Test 3: with a 'bad' label image */
             nullapert = cpl_apertures_new_from_image(img, NULL);
@@ -236,7 +232,7 @@ int main(void)
 
             if (type != CPL_TYPE_INT) {
                 /* Test (error) handling of a complex image */
-                cpl_image * imgc = cpl_image_cast(imd, type | CPL_TYPE_COMPLEX);
+                cpl_image *imgc = cpl_image_cast(imd, type | CPL_TYPE_COMPLEX);
 
                 aperts = cpl_apertures_new_from_image(imgc, labels);
                 cpl_test_error(CPL_ERROR_TYPE_MISMATCH);
@@ -262,7 +258,7 @@ int main(void)
             cpl_mask_delete(bin);
 
             /* Compute statistics on the apertures */
-            cpl_msg_info("","Compute statistics on detected apertures");
+            cpl_msg_info("", "Compute statistics on detected apertures");
             aperts = cpl_apertures_new_from_image(img, labels);
             cpl_test_error(CPL_ERROR_NONE);
             cpl_test_nonnull(aperts);
@@ -278,7 +274,8 @@ int main(void)
 
             cpl_apertures_test_one(aperts, stream);
 
-            cpl_msg_info("","Compare statistics with those from same "
+            cpl_msg_info("",
+                         "Compare statistics with those from same "
                          "image with %" CPL_SIZE_FORMAT "rejected pixels",
                          cpl_image_count_rejected(imb));
 
@@ -313,7 +310,7 @@ int main(void)
             cpl_test_leq(ypos, cpl_apertures_get_top(aperts, 1));
 
             cpl_apertures_delete(aperts);
-    
+
             /* Set a bad pixel and recompute the apertures */
             error = cpl_image_reject(img, 6, 6);
             cpl_test_eq_error(error, CPL_ERROR_NONE);
@@ -336,10 +333,10 @@ int main(void)
             cpl_image_delete(labels);
 
             /* Get the biggest object */
-            cpl_msg_info("","Get the biggest aperture:");
+            cpl_msg_info("", "Get the biggest aperture:");
             error = cpl_apertures_sort_by_npix(aperts);
             cpl_test_eq_error(error, CPL_ERROR_NONE);
-            cpl_msg_info("","number of pixels: %" CPL_SIZE_FORMAT,
+            cpl_msg_info("", "number of pixels: %" CPL_SIZE_FORMAT,
                          cpl_apertures_get_npix(aperts, 1));
 
             cpl_apertures_test_one(aperts, stream);
@@ -348,10 +345,10 @@ int main(void)
                          cpl_apertures_get_npix(aperts, 1));
 
             /* Get the brightest object */
-            cpl_msg_info("","Get the brightest aperture:");
+            cpl_msg_info("", "Get the brightest aperture:");
             error = cpl_apertures_sort_by_flux(aperts);
             cpl_test_eq_error(error, CPL_ERROR_NONE);
-            cpl_msg_info("","flux: %g", cpl_apertures_get_flux(aperts, 1));
+            cpl_msg_info("", "flux: %g", cpl_apertures_get_flux(aperts, 1));
 
             cpl_apertures_test_one(aperts, stream);
 
@@ -359,10 +356,11 @@ int main(void)
                          cpl_apertures_get_flux(aperts, 1));
 
             /* Get the aperture with the highest peak */
-            cpl_msg_info("","Get the aperture with the highest peak:");
+            cpl_msg_info("", "Get the aperture with the highest peak:");
             error = cpl_apertures_sort_by_max(aperts);
             cpl_test_eq_error(error, CPL_ERROR_NONE);
-            cpl_msg_info("","maximum value: %g", cpl_apertures_get_max(aperts, 1));
+            cpl_msg_info("", "maximum value: %g",
+                         cpl_apertures_get_max(aperts, 1));
 
             cpl_apertures_test_one(aperts, stream);
 
@@ -376,7 +374,7 @@ int main(void)
                 errsize = ap_get_cpl_size[isize](aperts, 0);
                 cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
                 cpl_test_lt(errsize, 0.0);
-                errsize = ap_get_cpl_size[isize](aperts, 1+naperts);
+                errsize = ap_get_cpl_size[isize](aperts, 1 + naperts);
                 cpl_test_error(CPL_ERROR_ACCESS_OUT_OF_RANGE);
                 cpl_test_lt(errsize, 0.0);
             }
@@ -385,7 +383,7 @@ int main(void)
                 double errpos = ap_get_double_pos[isize](aperts, 0);
                 cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
                 cpl_test_lt(errpos, 0.0);
-                errpos = ap_get_double_pos[isize](aperts, 1+naperts);
+                errpos = ap_get_double_pos[isize](aperts, 1 + naperts);
                 cpl_test_error(CPL_ERROR_ACCESS_OUT_OF_RANGE);
                 cpl_test_lt(errpos, 0.0);
             }
@@ -393,26 +391,25 @@ int main(void)
             for (isize = 0; isize < napdbl; isize++) {
                 (void)ap_get_double[isize](aperts, 0);
                 cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
-                (void)ap_get_double[isize](aperts, 1+naperts);
+                (void)ap_get_double[isize](aperts, 1 + naperts);
                 cpl_test_error(CPL_ERROR_ACCESS_OUT_OF_RANGE);
             }
 
             cpl_apertures_delete(aperts);
             cpl_image_delete(imb);
             cpl_image_delete(img);
-
         }
     }
 
     cpl_image_delete(imd);
- 
+
     /* Create a new test image */
     imd = cpl_image_fill_test_create(IMAGESZ2, IMAGESZ2);
-    
-    sigmas = cpl_vector_wrap(4, (double*)psigmas);
+
+    sigmas = cpl_vector_wrap(4, (double *)psigmas);
 
     /* Test cpl_apertures_extract() */
-    cpl_msg_info("","Test the apertures detection with a thresholding method");
+    cpl_msg_info("", "Test the apertures detection with a thresholding method");
     aperts = cpl_apertures_extract(imd, sigmas, &pos);
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_nonnull(aperts);
@@ -438,9 +435,10 @@ int main(void)
     cpl_test_null(nullapert);
 
     /* Test cpl_apertures_extract_window() */
-    cpl_msg_info("","Test the apertures detection (threshold) on a zone");
-    aperts = cpl_apertures_extract_window(imd, sigmas, IMAGESZ2/4, IMAGESZ2/4,
-                                          3*IMAGESZ2/4, 3*IMAGESZ2/4, &pos);
+    cpl_msg_info("", "Test the apertures detection (threshold) on a zone");
+    aperts =
+        cpl_apertures_extract_window(imd, sigmas, IMAGESZ2 / 4, IMAGESZ2 / 4,
+                                     3 * IMAGESZ2 / 4, 3 * IMAGESZ2 / 4, &pos);
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_nonnull(aperts);
 
@@ -456,7 +454,7 @@ int main(void)
     cpl_apertures_test_one(aperts, stream);
 
     for (pos = 1; pos < nsize; pos++) {
-        cpl_test_leq(cpl_apertures_get_max(aperts, pos+1),
+        cpl_test_leq(cpl_apertures_get_max(aperts, pos + 1),
                      cpl_apertures_get_max(aperts, pos));
     }
 
@@ -467,7 +465,7 @@ int main(void)
     cpl_apertures_test_one(aperts, stream);
 
     for (pos = 1; pos < nsize; pos++) {
-        cpl_test_leq(cpl_apertures_get_npix(aperts, pos+1),
+        cpl_test_leq(cpl_apertures_get_npix(aperts, pos + 1),
                      cpl_apertures_get_npix(aperts, pos));
     }
 
@@ -479,7 +477,7 @@ int main(void)
     cpl_apertures_test_one(aperts, stream);
 
     for (pos = 1; pos < nsize; pos++) {
-        cpl_test_leq(cpl_apertures_get_flux(aperts, pos+1),
+        cpl_test_leq(cpl_apertures_get_flux(aperts, pos + 1),
                      cpl_apertures_get_flux(aperts, pos));
     }
 
@@ -488,13 +486,13 @@ int main(void)
     cpl_image_delete(imd);
     cpl_mask_delete(bpm);
 
-    if (stream != stdout) cpl_test_zero( fclose(stream) );
+    if (stream != stdout)
+        cpl_test_zero(fclose(stream));
 
     return cpl_test_end(0);
 }
 
 
-
 /*----------------------------------------------------------------------------*/
 /**
   @internal
@@ -505,7 +503,8 @@ int main(void)
 
  */
 /*----------------------------------------------------------------------------*/
-static void cpl_apertures_test_one(const cpl_apertures * self, FILE * stream)
+static void
+cpl_apertures_test_one(const cpl_apertures *self, FILE *stream)
 {
     const cpl_size nsize = cpl_apertures_get_size(self);
     cpl_size i;
